@@ -15,8 +15,6 @@ def detrend(patch: PatchType, dim, type="linear") -> PatchType:
 
     Parameters
     ----------
-    PatchType
-        The patch instance you're applying the detrend function.
     dim
         The dimension ("distance" or "time") along where detrending is applied.
     type
@@ -31,7 +29,7 @@ def detrend(patch: PatchType, dim, type="linear") -> PatchType:
     --------
     >>> import dascore # import dascore library
     >>> pa = dascore.get_example_patch() # generate example patch
-    >>> out = dascore.proc.detrend(pa, "distance") # detrend in the distance dimension
+    >>> out = pa.detrend("time") # detrend along the time dimension
     """
     assert dim in patch.dims
     axis = patch.dims.index(dim)
