@@ -6,6 +6,7 @@ import numpy as np
 from dascore.constants import PatchType
 from dascore.utils.misc import _get_sampling_rate
 from dascore.utils.patch import patch_function
+from dascore.utils.transformatter import FourierTransformatter
 
 
 @patch_function()
@@ -24,13 +25,14 @@ def rfft(patch: PatchType, dim="time") -> PatchType:
     -----
     The real Fourier Transform is only appropriate for real-valued data arrays.
     """
+    ft = FourierTransformatter()
     data = patch.data
     axis = patch.dims.index(dim)
-    new_dim_name = f"frequency_{dim}"
     sr = 1 / _get_sampling_rate(patch.attrs[f"d_{dim}"])
     freqs = np.fft.rfftfreq(data.shape[axis], sr)
     new_data = np.fft.rfft(data, axis=axis)
-    new_dims = [(x if x != dim else new_dim_name) for x in patch.dims]
+    new_dim_name = ft._forward_rename(patch.dims[axis])
+    dims, attrs = ft.transform_dims_and_attrs(patch.dims, patch.attrs, index=axis)
     new_coords = {new_dim_name: freqs}
     new_coords.update({x: patch.coords[x] for x in patch.dims if x != dim})
-    return patch.__class__(data=new_data, coords=new_coords, dims=new_dims)
+    return patch.__class__(data=new_data, coords=new_coords, dims=dims, attrs=attrs)
