@@ -42,7 +42,7 @@ def _shallow_copy(patch: PatchType) -> PatchType:
 
     Note
     ----
-    This is an internal function because Patch should not be immutable with
+    This is an internal function because Patch should be immutable with
     the public APIs.
     """
     dar = patch._data_array.copy(deep=False)  # dont copy data and such
@@ -582,7 +582,7 @@ def _merge_patches(
         no_merge = ~(dist_to_previous <= merge_dist)
         sub_df["_dist_to_previous"] = dist_to_previous
         # determine if each patch should be merged with the previous one
-        for _, merge_patch_df in sub_df.groupby(no_merge.astype(int).cumsum()):
+        for _, merge_patch_df in sub_df.groupby(no_merge.astype(np.int64).cumsum()):
             out.append(_merge_compatible_patches(merge_patch_df))
     return out
 
