@@ -44,8 +44,8 @@ def contiguous_df_two_stations(contiguous_df):
     return pd.concat([df1, df2], axis=0, ignore_index=True)
 
 
-class TestArrange:
-    """Tests for custom arrange function."""
+class TestGetIntervals:
+    """Tests for generating intervals along some continuous dimension."""
 
     def test_numbers_no_overlap(self):
         """Ensure simple ints with no overlap work."""
@@ -155,11 +155,39 @@ class TestBasicChunkDF:
         _, out2 = chunker2.chunk(contiguous_df)
         assert out.equals(out2)
 
+    def test_chunk_on_split(self, terra15_file_spool):
+        """Ensure chunking which creates a slice at the end time works."""
+        # this spool was selected because I first observed the issue in it.
+        df = terra15_file_spool.get_contents()
+        dur = (df["time_max"] - df["time_min"]).iloc[0]
+        seg_len = dur / 3
+        dt = df["d_time"].iloc[0]
+        chunker = ChunkManager(keep_partial=True, time=seg_len)
+        _, chunk_df = chunker.chunk(df)
+        duration = chunk_df["time_max"] - chunk_df["time_min"]
+        assert duration.sum() == ((seg_len - dt) * 3)
+        assert len(duration) == 3
+        assert (duration > np.timedelta64(0, "s")).all()
+
+
+class TestChunkExceptions:
+    """Tests for various exceptions from the chunk manager."""
+
     def test_raises_overlap_no_chunksize(self):
         """Specifying an overlap and no chunk size should raise."""
         with pytest.raises(ParameterError, match="used for merging"):
             ChunkManager(time=None, overlap=10)
 
+    def test_raises_zero_length_multiple_kwargs(self):
+        """Ensure multiple kwargs raises nice error."""
+        with pytest.raises(ParameterError, match="along one dimension"):
+            ChunkManager(time=10, distance=1)
+
+    def test_raises_zero_length_chunk(self):
+        """Ensure zero length chunk raises."""
+        with pytest.raises(ParameterError, match="must be greater than 0"):
+            ChunkManager(time=0)
+
 
 class TestChunkToMerge:
     """Tests for using chunking to merge contiguous, or overlapping, data."""
