@@ -4,6 +4,7 @@ import pandas as pd
 import pydantic
 import pytest
 
+from dascore.exceptions import ParameterError
 from dascore.utils.pd import adjust_segments, fill_defaults_from_pydantic, filter_df
 from dascore.utils.time import to_datetime64, to_timedelta64
 
@@ -78,7 +79,7 @@ class TestFilterDfBasic:
 
     def test_bad_parameter_raises(self, example_df):
         """ensure passing a parameter that doesn't have a column raises."""
-        with pytest.raises(KeyError, match="not found in df"):
+        with pytest.raises(ParameterError, match="the column does not"):
             filter_df(example_df, bad_column=2)
 
     def test_bad_parameter_doesnt_raise(self, example_df):
@@ -137,14 +138,14 @@ class TestFilterDfAdvanced:
         tmax = to_datetime64(example_df_2["time_max"].max() - np.timedelta64(1, "ns"))
         out = filter_df(example_df_2, time=(tmax, None))
         # just the last row should have been selected
-        assert out.iloc[-1] and out.astype(int).sum() == 1
+        assert out.iloc[-1] and out.astype(np.int64).sum() == 1
 
     def test_time_query_with_string(self, example_df_2):
         """Test for time query with a string."""
         tmax = to_datetime64(example_df_2["time_max"].max() - np.timedelta64(1, "ns"))
         out1 = filter_df(example_df_2, time=(str(tmax), None))
         # just the last row should have been selected
-        assert out1.iloc[-1] and out1.astype(int).sum() == 1
+        assert out1.iloc[-1] and out1.astype(np.int64).sum() == 1
         # also ensure the string can be second element, all rows should be selected
         out2 = filter_df(example_df_2, time=(None, str(tmax)))
         assert len(out2) == len(example_df_2)
@@ -198,7 +199,7 @@ class TestAdjustSegments:
     def test_missing_interval_col_raises_keyerro(self, adjacent_df):
         """Ensure if an interval column is missing a KeyError is raised."""
         df = adjacent_df.drop(columns=["distance_min"])
-        with pytest.raises(KeyError):
+        with pytest.raises(ParameterError):
             _ = adjust_segments(df, distance=(100, 200))
 
     class TestFillDefaultsFromPydantic:
